@@ -5,14 +5,14 @@ use warnings;
 
 package Validation::Class;
 {
-    $Validation::Class::VERSION = '5.75';
+    $Validation::Class::VERSION = '5.80';
 }
 
 use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '5.75';    # VERSION
+our $VERSION = '5.80';    # VERSION
 
 use Module::Find;
 use Carp 'confess';
@@ -130,6 +130,8 @@ sub build {
 
     no strict 'refs';
 
+    $self->{config}->{BUILDERS} ||= [];
+
     push @{$self->{config}->{BUILDERS}}, $code;
 
     return $code;
@@ -237,6 +239,8 @@ sub load {
 
     no strict 'refs';
 
+    $self->{config}->{BUILDERS} ||= [];    # prevents merge from referencing
+
     if ($data->{class}) {
 
         my $classes = [];
@@ -665,7 +669,7 @@ Validation::Class - Low-Fat Full-Flavored Data Modeling and Validation Framework
 
 =head1 VERSION
 
-version 5.75
+version 5.80
 
 =head1 SYNOPSIS
 
