@@ -2,14 +2,14 @@
 
 package Validation::Class::Engine;
 {
-    $Validation::Class::Engine::VERSION = '5.75';
+    $Validation::Class::Engine::VERSION = '5.80';
 }
 
 use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '5.75';    # VERSION
+our $VERSION = '5.80';    # VERSION
 
 use Carp 'confess';
 use Array::Unique;
@@ -336,6 +336,18 @@ sub clone {
 }
 
 
+sub copy_errors {
+
+    my ($self, $target) = @_;
+
+    # copy errors from one class to another, both must be VC classes
+    $target->set_errors($self->get_errors) if $self->error_count;
+
+    return $self;
+
+}
+
+
 sub default_value {
 
     my ($self, $field_name) = @_;
@@ -793,6 +805,10 @@ sub template {
 
     {
 
+        ATTRIBUTES => {},
+
+        BUILDERS => {},
+
         DIRECTIVES => {
 
             '&toggle' => {
@@ -1582,6 +1598,8 @@ sub template {
 
         },
 
+        METHODS => {},
+
         MIXINS => {},
 
         PLUGINS => {},
@@ -2231,7 +2249,7 @@ Validation::Class::Engine - Data Validation Engine for Validation::Class
 
 =head1 VERSION
 
-version 5.75
+version 5.80
 
 =head1 SYNOPSIS
 
@@ -2563,6 +2581,21 @@ run-time.
     
     1;
 
+=head2 copy_errors
+
+The copy_errors method is used to copy error messages from one class to another.
+Both classes must be Validation::Class based and/or at-least implement the
+get_errors and set_errors methods.
+
+    $input = Class->new;
+    $other = $input->class('other');
+    
+    unless ($other->validate) {
+        
+        $other->copy_errors($input);
+        
+    }
+
 =head2 default_value
 
 The default_value method returns the absolute value (hardcoded, default or
